==> lxqt-config-0.9.0.tar.xz: lxqt-config-0.9.0/liblxqt-config-cursor/translations/lxqt-config-cursor_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../ui/selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Налаштування тем миші LXQt</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Оберіть тему курсорів, яку Ви бажаєте використовувати (наведіть на попереднй перегляд для перевірки курсору). &lt;b&gt;Сеанс LXQt потребує перезапуску щоб ці зміни подіяли&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Встановити нову тему...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">&amp;Призначити тему</translation>
    </message>
    <message>
        <location filename="../ui/selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>Вилу&amp;чити тему</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Закрити</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Збій XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Неможливо вилучити активну тему!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../ui/warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/liblxqt-config-cursor/translations/lxqt-config-cursor_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Налаштування тем миші LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Оберіть тему курсорів, яку Ви бажаєте використовувати (наведіть на попереднй перегляд для перевірки курсору). &lt;b&gt;Сеанс LXQt потребує перезапуску щоб ці зміни подіяли&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Встановити нову тему...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>Вилу&amp;чити тему</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>Збій XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Неможливо вилучити активну тему!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt не може знайти жодної теми курсору. Буде використана типова тема курсору X11. LXQt шукало наступних теках:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Показ...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Опис</translation>
    </message>
</context>
</TS>
